==> android-2.3.3-sources.jar: android/Manifest.java <==
package android;
public final class Manifest
{
public static final class permission
{
public  permission() { throw new RuntimeException("Stub!"); }
public static final java.lang.String ACCESS_CHECKIN_PROPERTIES = "android.permission.ACCESS_CHECKIN_PROPERTIES";
public static final java.lang.String ACCESS_COARSE_LOCATION = "android.permission.ACCESS_COARSE_LOCATION";
public static final java.lang.String ACCESS_FINE_LOCATION = "android.permission.ACCESS_FINE_LOCATION";
public static final java.lang.String ACCESS_LOCATION_EXTRA_COMMANDS = "android.permission.ACCESS_LOCATION_EXTRA_COMMANDS";
public static final java.lang.String ACCESS_MOCK_LOCATION = "android.permission.ACCESS_MOCK_LOCATION";
public static final java.lang.String ACCESS_NETWORK_STATE = "android.permission.ACCESS_NETWORK_STATE";
public static final java.lang.String ACCESS_SURFACE_FLINGER = "android.permission.ACCESS_SURFACE_FLINGER";
public static final java.lang.String ACCESS_WIFI_STATE = "android.permission.ACCESS_WIFI_STATE";
public static final java.lang.String ACCOUNT_MANAGER = "android.permission.ACCOUNT_MANAGER";
public static final java.lang.String AUTHENTICATE_ACCOUNTS = "android.permission.AUTHENTICATE_ACCOUNTS";
public static final java.lang.String BATTERY_STATS = "android.permission.BATTERY_STATS";
public static final java.lang.String BIND_APPWIDGET = "android.permission.BIND_APPWIDGET";
public static final java.lang.String BIND_DEVICE_ADMIN = "android.permission.BIND_DEVICE_ADMIN";
public static final java.lang.String BIND_INPUT_METHOD = "android.permission.BIND_INPUT_METHOD";
public static final java.lang.String BIND_WALLPAPER = "android.permission.BIND_WALLPAPER";
public static final java.lang.String BLUETOOTH = "android.permission.BLUETOOTH";
public static final java.lang.String BLUETOOTH_ADMIN = "android.permission.BLUETOOTH_ADMIN";
public static final java.lang.String BRICK = "android.permission.BRICK";
public static final java.lang.String BROADCAST_PACKAGE_REMOVED = "android.permission.BROADCAST_PACKAGE_REMOVED";
public static final java.lang.String BROADCAST_SMS = "android.permission.BROADCAST_SMS";
public static final java.lang.String BROADCAST_STICKY = "android.permission.BROADCAST_STICKY";
public static final java.lang.String BROADCAST_WAP_PUSH = "android.permission.BROADCAST_WAP_PUSH";
public static final java.lang.String CALL_PHONE = "android.permission.CALL_PHONE";
public static final java.lang.String CALL_PRIVILEGED = "android.permission.CALL_PRIVILEGED";
public static final java.lang.String CAMERA = "android.permission.CAMERA";
public static final java.lang.String CHANGE_COMPONENT_ENABLED_STATE = "android.permission.CHANGE_COMPONENT_ENABLED_STATE";
public static final java.lang.String CHANGE_CONFIGURATION = "android.permission.CHANGE_CONFIGURATION";
public static final java.lang.String CHANGE_NETWORK_STATE = "android.permission.CHANGE_NETWORK_STATE";
public static final java.lang.String CHANGE_WIFI_MULTICAST_STATE = "android.permission.CHANGE_WIFI_MULTICAST_STATE";
public static final java.lang.String CHANGE_WIFI_STATE = "android.permission.CHANGE_WIFI_STATE";
public static final java.lang.String CLEAR_APP_CACHE = "android.permission.CLEAR_APP_CACHE";
public static final java.lang.String CLEAR_APP_USER_DATA = "android.permission.CLEAR_APP_USER_DATA";
public static final java.lang.String CONTROL_LOCATION_UPDATES = "android.permission.CONTROL_LOCATION_UPDATES";
public static final java.lang.String DELETE_CACHE_FILES = "android.permission.DELETE_CACHE_FILES";
public static final java.lang.String DELETE_PACKAGES = "android.permission.DELETE_PACKAGES";
public static final java.lang.String DEVICE_POWER = "android.permission.DEVICE_POWER";
public static final java.lang.String DIAGNOSTIC = "android.permission.DIAGNOSTIC";
public static final java.lang.String DISABLE_KEYGUARD = "android.permission.DISABLE_KEYGUARD";
public static final java.lang.String DUMP = "android.permission.DUMP";
public static final java.lang.String EXPAND_STATUS_BAR = "android.permission.EXPAND_STATUS_BAR";
public static final java.lang.String FACTORY_TEST = "android.permission.FACTORY_TEST";
public static final java.lang.String FLASHLIGHT = "android.permission.FLASHLIGHT";
public static final java.lang.String FORCE_BACK = "android.permission.FORCE_BACK";
public static final java.lang.String GET_ACCOUNTS = "android.permission.GET_ACCOUNTS";
public static final java.lang.String GET_PACKAGE_SIZE = "android.permission.GET_PACKAGE_SIZE";
public static final java.lang.String GET_TASKS = "android.permission.GET_TASKS";
public static final java.lang.String GLOBAL_SEARCH = "android.permission.GLOBAL_SEARCH";
public static final java.lang.String HARDWARE_TEST = "android.permission.HARDWARE_TEST";
public static final java.lang.String INJECT_EVENTS = "android.permission.INJECT_EVENTS";
public static final java.lang.String INSTALL_LOCATION_PROVIDER = "android.permission.INSTALL_LOCATION_PROVIDER";
public static final java.lang.String INSTALL_PACKAGES = "android.permission.INSTALL_PACKAGES";
public static final java.lang.String INTERNAL_SYSTEM_WINDOW = "android.permission.INTERNAL_SYSTEM_WINDOW";
public static final java.lang.String INTERNET = "android.permission.INTERNET";
public static final java.lang.String KILL_BACKGROUND_PROCESSES = "android.permission.KILL_BACKGROUND_PROCESSES";
public static final java.lang.String MANAGE_ACCOUNTS = "android.permission.MANAGE_ACCOUNTS";
public static final java.lang.String MANAGE_APP_TOKENS = "android.permission.MANAGE_APP_TOKENS";
public static final java.lang.String MASTER_CLEAR = "android.permission.MASTER_CLEAR";
public static final java.lang.String MODIFY_AUDIO_SETTINGS = "android.permission.MODIFY_AUDIO_SETTINGS";
public static final java.lang.String MODIFY_PHONE_STATE = "android.permission.MODIFY_PHONE_STATE";
public static final java.lang.String MOUNT_FORMAT_FILESYSTEMS = "android.permission.MOUNT_FORMAT_FILESYSTEMS";
public static final java.lang.String MOUNT_UNMOUNT_FILESYSTEMS = "android.permission.MOUNT_UNMOUNT_FILESYSTEMS";
public static final java.lang.String NFC = "android.permission.NFC";
public static final java.lang.String PERSISTENT_ACTIVITY = "android.permission.PERSISTENT_ACTIVITY";
public static final java.lang.String PROCESS_OUTGOING_CALLS = "android.permission.PROCESS_OUTGOING_CALLS";
public static final java.lang.String READ_CALENDAR = "android.permission.READ_CALENDAR";
public static final java.lang.String READ_CONTACTS = "android.permission.READ_CONTACTS";
public static final java.lang.String READ_FRAME_BUFFER = "android.permission.READ_FRAME_BUFFER";
public static final java.lang.String READ_HISTORY_BOOKMARKS = "com.android.browser.permission.READ_HISTORY_BOOKMARKS";
public static final java.lang.String READ_INPUT_STATE = "android.permission.READ_INPUT_STATE";
public static final java.lang.String READ_LOGS = "android.permission.READ_LOGS";
public static final java.lang.String READ_PHONE_STATE = "android.permission.READ_PHONE_STATE";
public static final java.lang.String READ_SMS = "android.permission.READ_SMS";
public static final java.lang.String READ_SYNC_SETTINGS = "android.permission.READ_SYNC_SETTINGS";
public static final java.lang.String READ_SYNC_STATS = "android.permission.READ_SYNC_STATS";
public static final java.lang.String REBOOT = "android.permission.REBOOT";
public static final java.lang.String RECEIVE_BOOT_COMPLETED = "android.permission.RECEIVE_BOOT_COMPLETED";
public static final java.lang.String RECEIVE_MMS = "android.permission.RECEIVE_MMS";
public static final java.lang.String RECEIVE_SMS = "android.permission.RECEIVE_SMS";
public static final java.lang.String RECEIVE_WAP_PUSH = "android.permission.RECEIVE_WAP_PUSH";
public static final java.lang.String RECORD_AUDIO = "android.permission.RECORD_AUDIO";
public static final java.lang.String REORDER_TASKS = "android.permission.REORDER_TASKS";
public static final java.lang.String RESTART_PACKAGES = "android.permission.RESTART_PACKAGES";
public static final java.lang.String SEND_SMS = "android.permission.SEND_SMS";
public static final java.lang.String SET_ACTIVITY_WATCHER = "android.permission.SET_ACTIVITY_WATCHER";
public static final java.lang.String SET_ALARM = "com.android.alarm.permission.SET_ALARM";
public static final java.lang.String SET_ALWAYS_FINISH = "android.permission.SET_ALWAYS_FINISH";
public static final java.lang.String SET_ANIMATION_SCALE = "android.permission.SET_ANIMATION_SCALE";
public static final java.lang.String SET_DEBUG_APP = "android.permission.SET_DEBUG_APP";
public static final java.lang.String SET_ORIENTATION = "android.permission.SET_ORIENTATION";
public static final java.lang.String SET_PREFERRED_APPLICATIONS = "android.permission.SET_PREFERRED_APPLICATIONS";
public static final java.lang.String SET_PROCESS_LIMIT = "android.permission.SET_PROCESS_LIMIT";
public static final java.lang.String SET_TIME = "android.permission.SET_TIME";
public static final java.lang.String SET_TIME_ZONE = "android.permission.SET_TIME_ZONE";
public static final java.lang.String SET_WALLPAPER = "android.permission.SET_WALLPAPER";
public static final java.lang.String SET_WALLPAPER_HINTS = "android.permission.SET_WALLPAPER_HINTS";
public static final java.lang.String SIGNAL_PERSISTENT_PROCESSES = "android.permission.SIGNAL_PERSISTENT_PROCESSES";
public static final java.lang.String STATUS_BAR = "android.permission.STATUS_BAR";
public static final java.lang.String SUBSCRIBED_FEEDS_READ = "android.permission.SUBSCRIBED_FEEDS_READ";
public static final java.lang.String SUBSCRIBED_FEEDS_WRITE = "android.permission.SUBSCRIBED_FEEDS_WRITE";
public static final java.lang.String SYSTEM_ALERT_WINDOW = "android.permission.SYSTEM_ALERT_WINDOW";
public static final java.lang.String UPDATE_DEVICE_STATS = "android.permission.UPDATE_DEVICE_STATS";
public static final java.lang.String USE_CREDENTIALS = "android.permission.USE_CREDENTIALS";
public static final java.lang.String USE_SIP = "android.permission.USE_SIP";
public static final java.lang.String VIBRATE = "android.permission.VIBRATE";
public static final java.lang.String WAKE_LOCK = "android.permission.WAKE_LOCK";
public static final java.lang.String WRITE_APN_SETTINGS = "android.permission.WRITE_APN_SETTINGS";
public static final java.lang.String WRITE_CALENDAR = "android.permission.WRITE_CALENDAR";
public static final java.lang.String WRITE_CONTACTS = "android.permission.WRITE_CONTACTS";
public static final java.lang.String WRITE_EXTERNAL_STORAGE = "android.permission.WRITE_EXTERNAL_STORAGE";
public static final java.lang.String WRITE_GSERVICES = "android.permission.WRITE_GSERVICES";
public static final java.lang.String WRITE_HISTORY_BOOKMARKS = "com.android.browser.permission.WRITE_HISTORY_BOOKMARKS";
public static final java.lang.String WRITE_SECURE_SETTINGS = "android.permission.WRITE_SECURE_SETTINGS";
public static final java.lang.String WRITE_SETTINGS = "android.permission.WRITE_SETTINGS";
public static final java.lang.String WRITE_SMS = "android.permission.WRITE_SMS";
public static final java.lang.String WRITE_SYNC_SETTINGS = "android.permission.WRITE_SYNC_SETTINGS";
}
public static final class permission_group
{
public  permission_group() { throw new RuntimeException("Stub!"); }
public static final java.lang.String ACCOUNTS = "android.permission-group.ACCOUNTS";
public static final java.lang.String COST_MONEY = "android.permission-group.COST_MONEY";
public static final java.lang.String DEVELOPMENT_TOOLS = "android.permission-group.DEVELOPMENT_TOOLS";
public static final java.lang.String HARDWARE_CONTROLS = "android.permission-group.HARDWARE_CONTROLS";
public static final java.lang.String LOCATION = "android.permission-group.LOCATION";
public static final java.lang.String MESSAGES = "android.permission-group.MESSAGES";
public static final java.lang.String NETWORK = "android.permission-group.NETWORK";
public static final java.lang.String PERSONAL_INFO = "android.permission-group.PERSONAL_INFO";
public static final java.lang.String PHONE_CALLS = "android.permission-group.PHONE_CALLS";
public static final java.lang.String STORAGE = "android.permission-group.STORAGE";
public static final java.lang.String SYSTEM_TOOLS = "android.permission-group.SYSTEM_TOOLS";
}
public  Manifest() { throw new RuntimeException("Stub!"); }
}

==> android-4.0.1.2-sources.jar: android/Manifest.java <==
package android;
public final class Manifest
{
public static final class permission
{
public  permission() { throw new RuntimeException("Stub!"); }
public static final java.lang.String ACCESS_CHECKIN_PROPERTIES = "android.permission.ACCESS_CHECKIN_PROPERTIES";
public static final java.lang.String ACCESS_COARSE_LOCATION = "android.permission.ACCESS_COARSE_LOCATION";
public static final java.lang.String ACCESS_FINE_LOCATION = "android.permission.ACCESS_FINE_LOCATION";
public static final java.lang.String ACCESS_LOCATION_EXTRA_COMMANDS = "android.permission.ACCESS_LOCATION_EXTRA_COMMANDS";
public static final java.lang.String ACCESS_MOCK_LOCATION = "android.permission.ACCESS_MOCK_LOCATION";
public static final java.lang.String ACCESS_NETWORK_STATE = "android.permission.ACCESS_NETWORK_STATE";
public static final java.lang.String ACCESS_SURFACE_FLINGER = "android.permission.ACCESS_SURFACE_FLINGER";
public static final java.lang.String ACCESS_WIFI_STATE = "android.permission.ACCESS_WIFI_STATE";
public static final java.lang.String ACCOUNT_MANAGER = "android.permission.ACCOUNT_MANAGER";
public static final java.lang.String ADD_VOICEMAIL = "com.android.voicemail.permission.ADD_VOICEMAIL";
public static final java.lang.String AUTHENTICATE_ACCOUNTS = "android.permission.AUTHENTICATE_ACCOUNTS";
public static final java.lang.String BATTERY_STATS = "android.permission.BATTERY_STATS";
public static final java.lang.String BIND_APPWIDGET = "android.permission.BIND_APPWIDGET";
public static final java.lang.String BIND_DEVICE_ADMIN = "android.permission.BIND_DEVICE_ADMIN";
public static final java.lang.String BIND_INPUT_METHOD = "android.permission.BIND_INPUT_METHOD";
public static final java.lang.String BIND_REMOTEVIEWS = "android.permission.BIND_REMOTEVIEWS";
public static final java.lang.String BIND_TEXT_SERVICE = "android.permission.BIND_TEXT_SERVICE";
public static final java.lang.String BIND_VPN_SERVICE = "android.permission.BIND_VPN_SERVICE";
public static final java.lang.String BIND_WALLPAPER = "android.permission.BIND_WALLPAPER";
public static final java.lang.String BLUETOOTH = "android.permission.BLUETOOTH";
public static final java.lang.String BLUETOOTH_ADMIN = "android.permission.BLUETOOTH_ADMIN";
public static final java.lang.String BRICK = "android.permission.BRICK";
public static final java.lang.String BROADCAST_PACKAGE_REMOVED = "android.permission.BROADCAST_PACKAGE_REMOVED";
public static final java.lang.String BROADCAST_SMS = "android.permission.BROADCAST_SMS";
public static final java.lang.String BROADCAST_STICKY = "android.permission.BROADCAST_STICKY";
public static final java.lang.String BROADCAST_WAP_PUSH = "android.permission.BROADCAST_WAP_PUSH";
public static final java.lang.String CALL_PHONE = "android.permission.CALL_PHONE";
public static final java.lang.String CALL_PRIVILEGED = "android.permission.CALL_PRIVILEGED";
public static final java.lang.String CAMERA = "android.permission.CAMERA";
public static final java.lang.String CHANGE_COMPONENT_ENABLED_STATE = "android.permission.CHANGE_COMPONENT_ENABLED_STATE";
public static final java.lang.String CHANGE_CONFIGURATION = "android.permission.CHANGE_CONFIGURATION";
public static final java.lang.String CHANGE_NETWORK_STATE = "android.permission.CHANGE_NETWORK_STATE";
public static final java.lang.String CHANGE_WIFI_MULTICAST_STATE = "android.permission.CHANGE_WIFI_MULTICAST_STATE";
public static final java.lang.String CHANGE_WIFI_STATE = "android.permission.CHANGE_WIFI_STATE";
public static final java.lang.String CLEAR_APP_CACHE = "android.permission.CLEAR_APP_CACHE";
public static final java.lang.String CLEAR_APP_USER_DATA = "android.permission.CLEAR_APP_USER_DATA";
public static final java.lang.String CONTROL_LOCATION_UPDATES = "android.permission.CONTROL_LOCATION_UPDATES";
public static final java.lang.String DELETE_CACHE_FILES = "android.permission.DELETE_CACHE_FILES";
public static final java.lang.String DELETE_PACKAGES = "android.permission.DELETE_PACKAGES";
public static final java.lang.String DEVICE_POWER = "android.permission.DEVICE_POWER";
public static final java.lang.String DIAGNOSTIC = "android.permission.DIAGNOSTIC";
public static final java.lang.String DISABLE_KEYGUARD = "android.permission.DISABLE_KEYGUARD";
public static final java.lang.String DUMP = "android.permission.DUMP";
public static final java.lang.String EXPAND_STATUS_BAR = "android.permission.EXPAND_STATUS_BAR";
public static final java.lang.String FACTORY_TEST = "android.permission.FACTORY_TEST";
public static final java.lang.String FLASHLIGHT = "android.permission.FLASHLIGHT";
public static final java.lang.String FORCE_BACK = "android.permission.FORCE_BACK";
public static final java.lang.String GET_ACCOUNTS = "android.permission.GET_ACCOUNTS";
public static final java.lang.String GET_PACKAGE_SIZE = "android.permission.GET_PACKAGE_SIZE";
public static final java.lang.String GET_TASKS = "android.permission.GET_TASKS";
public static final java.lang.String GLOBAL_SEARCH = "android.permission.GLOBAL_SEARCH";
public static final java.lang.String HARDWARE_TEST = "android.permission.HARDWARE_TEST";
public static final java.lang.String INJECT_EVENTS = "android.permission.INJECT_EVENTS";
public static final java.lang.String INSTALL_LOCATION_PROVIDER = "android.permission.INSTALL_LOCATION_PROVIDER";
public static final java.lang.String INSTALL_PACKAGES = "android.permission.INSTALL_PACKAGES";
public static final java.lang.String INTERNAL_SYSTEM_WINDOW = "android.permission.INTERNAL_SYSTEM_WINDOW";
public static final java.lang.String INTERNET = "android.permission.INTERNET";
public static final java.lang.String KILL_BACKGROUND_PROCESSES = "android.permission.KILL_BACKGROUND_PROCESSES";
public static final java.lang.String MANAGE_ACCOUNTS = "android.permission.MANAGE_ACCOUNTS";
public static final java.lang.String MANAGE_APP_TOKENS = "android.permission.MANAGE_APP_TOKENS";
public static final java.lang.String MASTER_CLEAR = "android.permission.MASTER_CLEAR";
public static final java.lang.String MODIFY_AUDIO_SETTINGS = "android.permission.MODIFY_AUDIO_SETTINGS";
public static final java.lang.String MODIFY_PHONE_STATE = "android.permission.MODIFY_PHONE_STATE";
public static final java.lang.String MOUNT_FORMAT_FILESYSTEMS = "android.permission.MOUNT_FORMAT_FILESYSTEMS";
public static final java.lang.String MOUNT_UNMOUNT_FILESYSTEMS = "android.permission.MOUNT_UNMOUNT_FILESYSTEMS";
public static final java.lang.String NFC = "android.permission.NFC";
public static final java.lang.String PERSISTENT_ACTIVITY = "android.permission.PERSISTENT_ACTIVITY";
public static final java.lang.String PROCESS_OUTGOING_CALLS = "android.permission.PROCESS_OUTGOING_CALLS";
public static final java.lang.String READ_CALENDAR = "android.permission.READ_CALENDAR";
public static final java.lang.String READ_CONTACTS = "android.permission.READ_CONTACTS";
public static final java.lang.String READ_FRAME_BUFFER = "android.permission.READ_FRAME_BUFFER";
public static final java.lang.String READ_HISTORY_BOOKMARKS = "com.android.browser.permission.READ_HISTORY_BOOKMARKS";
public static final java.lang.String READ_INPUT_STATE = "android.permission.READ_INPUT_STATE";
public static final java.lang.String READ_LOGS = "android.permission.READ_LOGS";
public static final java.lang.String READ_PHONE_STATE = "android.permission.READ_PHONE_STATE";
public static final java.lang.String READ_PROFILE = "android.permission.READ_PROFILE";
public static final java.lang.String READ_SMS = "android.permission.READ_SMS";
public static final java.lang.String READ_SYNC_SETTINGS = "android.permission.READ_SYNC_SETTINGS";
public static final java.lang.String READ_SYNC_STATS = "android.permission.READ_SYNC_STATS";
public static final java.lang.String REBOOT = "android.permission.REBOOT";
public static final java.lang.String RECEIVE_BOOT_COMPLETED = "android.permission.RECEIVE_BOOT_COMPLETED";
public static final java.lang.String RECEIVE_MMS = "android.permission.RECEIVE_MMS";
public static final java.lang.String RECEIVE_SMS = "android.permission.RECEIVE_SMS";
public static final java.lang.String RECEIVE_WAP_PUSH = "android.permission.RECEIVE_WAP_PUSH";
public static final java.lang.String RECORD_AUDIO = "android.permission.RECORD_AUDIO";
public static final java.lang.String REORDER_TASKS = "android.permission.REORDER_TASKS";
public static final java.lang.String RESTART_PACKAGES = "android.permission.RESTART_PACKAGES";
public static final java.lang.String SEND_SMS = "android.permission.SEND_SMS";
public static final java.lang.String SET_ACTIVITY_WATCHER = "android.permission.SET_ACTIVITY_WATCHER";
public static final java.lang.String SET_ALARM = "com.android.alarm.permission.SET_ALARM";
public static final java.lang.String SET_ALWAYS_FINISH = "android.permission.SET_ALWAYS_FINISH";
public static final java.lang.String SET_ANIMATION_SCALE = "android.permission.SET_ANIMATION_SCALE";
public static final java.lang.String SET_DEBUG_APP = "android.permission.SET_DEBUG_APP";
public static final java.lang.String SET_ORIENTATION = "android.permission.SET_ORIENTATION";
public static final java.lang.String SET_POINTER_SPEED = "android.permission.SET_POINTER_SPEED";
public static final java.lang.String SET_PREFERRED_APPLICATIONS = "android.permission.SET_PREFERRED_APPLICATIONS";
public static final java.lang.String SET_PROCESS_LIMIT = "android.permission.SET_PROCESS_LIMIT";
public static final java.lang.String SET_TIME = "android.permission.SET_TIME";
public static final java.lang.String SET_TIME_ZONE = "android.permission.SET_TIME_ZONE";
public static final java.lang.String SET_WALLPAPER = "android.permission.SET_WALLPAPER";
public static final java.lang.String SET_WALLPAPER_HINTS = "android.permission.SET_WALLPAPER_HINTS";
public static final java.lang.String SIGNAL_PERSISTENT_PROCESSES = "android.permission.SIGNAL_PERSISTENT_PROCESSES";
public static final java.lang.String STATUS_BAR = "android.permission.STATUS_BAR";
public static final java.lang.String SUBSCRIBED_FEEDS_READ = "android.permission.SUBSCRIBED_FEEDS_READ";
public static final java.lang.String SUBSCRIBED_FEEDS_WRITE = "android.permission.SUBSCRIBED_FEEDS_WRITE";
public static final java.lang.String SYSTEM_ALERT_WINDOW = "android.permission.SYSTEM_ALERT_WINDOW";
public static final java.lang.String UPDATE_DEVICE_STATS = "android.permission.UPDATE_DEVICE_STATS";
public static final java.lang.String USE_CREDENTIALS = "android.permission.USE_CREDENTIALS";
public static final java.lang.String USE_SIP = "android.permission.USE_SIP";
public static final java.lang.String VIBRATE = "android.permission.VIBRATE";
public static final java.lang.String WAKE_LOCK = "android.permission.WAKE_LOCK";
public static final java.lang.String WRITE_APN_SETTINGS = "android.permission.WRITE_APN_SETTINGS";
public static final java.lang.String WRITE_CALENDAR = "android.permission.WRITE_CALENDAR";
public static final java.lang.String WRITE_CONTACTS = "android.permission.WRITE_CONTACTS";
public static final java.lang.String WRITE_EXTERNAL_STORAGE = "android.permission.WRITE_EXTERNAL_STORAGE";
public static final java.lang.String WRITE_GSERVICES = "android.permission.WRITE_GSERVICES";
public static final java.lang.String WRITE_HISTORY_BOOKMARKS = "com.android.browser.permission.WRITE_HISTORY_BOOKMARKS";
public static final java.lang.String WRITE_PROFILE = "android.permission.WRITE_PROFILE";
public static final java.lang.String WRITE_SECURE_SETTINGS = "android.permission.WRITE_SECURE_SETTINGS";
public static final java.lang.String WRITE_SETTINGS = "android.permission.WRITE_SETTINGS";
public static final java.lang.String WRITE_SMS = "android.permission.WRITE_SMS";
public static final java.lang.String WRITE_SYNC_SETTINGS = "android.permission.WRITE_SYNC_SETTINGS";
}
public static final class permission_group
{
public  permission_group() { throw new RuntimeException("Stub!"); }
public static final java.lang.String ACCOUNTS = "android.permission-group.ACCOUNTS";
public static final java.lang.String COST_MONEY = "android.permission-group.COST_MONEY";
public static final java.lang.String DEVELOPMENT_TOOLS = "android.permission-group.DEVELOPMENT_TOOLS";
public static final java.lang.String HARDWARE_CONTROLS = "android.permission-group.HARDWARE_CONTROLS";
public static final java.lang.String LOCATION = "android.permission-group.LOCATION";
public static final java.lang.String MESSAGES = "android.permission-group.MESSAGES";
public static final java.lang.String NETWORK = "android.permission-group.NETWORK";
public static final java.lang.String PERSONAL_INFO = "android.permission-group.PERSONAL_INFO";
public static final java.lang.String PHONE_CALLS = "android.permission-group.PHONE_CALLS";
public static final java.lang.String STORAGE = "android.permission-group.STORAGE";
public static final java.lang.String SYSTEM_TOOLS = "android.permission-group.SYSTEM_TOOLS";
}
public  Manifest() { throw new RuntimeException("Stub!"); }
}
